@@ -5,14 +5,12 @@ import click
 
 from contxt.auth.cli import CliAuth
 from contxt.services import (
-    AssetsService,
     ContxtDeploymentService,
     ContxtService,
     EmsService,
     EventsService,
-    FacilitiesService,
-    HealthService,
     IotService,
+    NionicService,
     SisService,
 )
 from contxt.utils import cachedproperty
@@ -43,10 +41,6 @@ class Clients:
     def auth(self) -> CliAuth:
         return CliAuth(env=self.env)
 
-    @cachedproperty
-    def assets(self) -> AssetsService:
-        return AssetsService(auth=self.auth, env=self.env)
-
     @cachedproperty
     def contxt(self) -> ContxtService:
         return ContxtService(auth=self.auth, env=self.env)
@@ -57,19 +51,15 @@ class Clients:
 
     @cachedproperty
     def ems(self) -> EmsService:
-        return EmsService(auth=self.auth, env=self.env)
+        return EmsService(auth=self.auth, env=self.env, org_id=self.org_id)
 
     @cachedproperty
     def events(self) -> EventsService:
         return EventsService(auth=self.auth, env=self.env)
 
     @cachedproperty
-    def facilities(self) -> FacilitiesService:
-        return FacilitiesService(auth=self.auth, env=self.env)
-
-    @cachedproperty
-    def health(self) -> HealthService:
-        return HealthService(auth=self.auth, env=self.env)
+    def nionic(self) -> NionicService:
+        return NionicService(auth=self.auth, env=self.env, org_id=self.org_id)
 
     @cachedproperty
     def iot(self) -> IotService:
